izulu documentation
===================

.. list-table::

   * - .. image:: https://repository-images.githubusercontent.com/766241795/85494614-5974-4b26-bfec-03b8e393c7f0
          :width: 256px

       |

       .. epigraph::

          *"The exceptional library"*

       |

       | **Author:** Dima Burmistrov (`pyctrl <https://github.com/pyctrl>`__)
       | *Special thanks to* `Eugene Frolov <https://github.com/phantomii/>`__ *for inspiration.*
       |

       This project is `licensed <https://github.com/pyctrl/izulu/blob/main/LICENSE>`__ under the X11 License (extended MIT).


     - .. toctree::
          :maxdepth: 2

          user/index
          specs/index
          ref
          contributors
